import { LocaleConfig, PluginFunction } from '@vuepress/core';
import { ConvertLocaleConfig } from '@mr-hope/vuepress-shared';

interface BackToTopLocaleData {
    /**
     * Back to top button label text
     *
     * 返回顶部文字
     */
    backToTop: string;
}
declare type BackToTopLocaleConfig = ConvertLocaleConfig<BackToTopLocaleData>;

declare type AvailableComponent = "Badge";
interface ComponentOptions {
    /**
     * Components to be registered
     *
     * 需要被注册的组件
     *
     * @default []
     */
    components: AvailableComponent[];
    /**
     * Whether enabling backToTop button
     *
     * 是否启用返回顶部按钮
     *
     * @default false
     */
    backToTop?: boolean;
    /**
     * backToTop button threshold distance (in pixels)
     *
     * 返回顶部按钮触发距离 (单位：像素)
     *
     * @default 300
     */
    backToTopThreshold?: number;
    /**
     * backToTop button Locales config
     *
     * 返回顶部按钮国际化配置
     */
    backToTopLocales?: LocaleConfig<BackToTopLocaleData>;
}

declare const componentsPlugin: (options: ComponentOptions) => PluginFunction;

export { AvailableComponent, BackToTopLocaleConfig, BackToTopLocaleData, ComponentOptions, componentsPlugin, componentsPlugin as default };
